#
# spec file for package compizconfig-settings-manager
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _name   ccsm
Name:           compizconfig-settings-manager
Version:        0.8.14
Release:        lp150.1.6
Summary:        Settings Manager for Compiz (CCSM)
License:        GPL-2.0+
Group:          System/X11/Utilities
Url:            https://github.com/compiz-reloaded/ccsm
Source:         https://github.com/compiz-reloaded/%{_name}/releases/download/v%{version}/%{_name}-%{version}.tar.xz
BuildRequires:  gettext
BuildRequires:  gobject-introspection-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  python3-devel
BuildRequires:  update-desktop-files
Requires:       python3-ccm = %{version}
Recommends:     %{name}-lang
Provides:       %{_name} = 0.8
BuildArch:      noarch

%description
Compiz Config and Settings tool (CCSM).

%lang_package

%package -n compizconfig-settings-manager-common
Summary:        Settings Manager for Compiz -- Common files
Group:          System/X11/Utilities
BuildArch:      noarch

%description -n compizconfig-settings-manager-common
Common files for the Compiz Config and Settings tool (CCSM).

%package -n python3-ccm
Summary:        CompizConfig Manager Backend
Group:          Development/Languages/Python
Requires:       compiz < 0.9
Requires:       compizconfig-settings-manager-common
Requires:       python3-cairo
Requires:       python3-compizconfig < 0.9
Requires:       python3-gobject
Requires:       python3-gobject-cairo
Requires:       python3-xml
Obsoletes:      python-ccm < 0.8.14
%if 0%{?suse_version} > 1320 || 0%{?sle_version} >= 120200
Requires:       python3-gobject-Gdk
%endif

%description -n python3-ccm
The backend to Compiz Config Manager.

%prep
%setup -q -n %{_name}-%{version}
mv ccsm.appdata.xml{,.in}

%build
python3 setup.py build \
  --prefix=%{_prefix}

%install
python3 setup.py install \
  --root=%{buildroot} \
  --prefix=%{_prefix}
mv %{buildroot}%{_datadir}/{metainfo,appdata}/
%find_lang %{_name}

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc COPYING NEWS
%{_bindir}/%{_name}
%{_datadir}/applications/%{_name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{_name}.*
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{_name}.appdata.xml

%files lang -f %{_name}.lang
%defattr(-,root,root)

%files -n compizconfig-settings-manager-common
%defattr(-,root,root)
%{_datadir}/%{_name}/

%files -n python3-ccm
%defattr(-,root,root)
%{python3_sitelib}/ccm/
%{python3_sitelib}/%{_name}*

%changelog
* Tue Apr 18 2017 sor.alexei@meowr.ru
- Update to version 0.8.14:
  * Fixes for Python3.
  * Introduce window state selector.
  * Add an icon for the Earth plugin.
  * Update translations.
- Switch to Python3.
- Separate shared files from python3-ccm to
  compizconfig-settings-manager-common.
* Fri May 27 2016 sor.alexei@meowr.ru
- Update to version 0.8.12.4:
  * Gtk3: Remove a warning with some file chooser dialogs.
  * Gtk3: Verify colour set for titles to not be equal to bgcolour.
  * Update Catalan translation.
* Wed May  4 2016 sor.alexei@meowr.ru
- Add a missing python-gobject-Gdk dependency.
* Mon Mar 28 2016 sor.alexei@meowr.ru
- Update to version 0.8.12.3:
  * Gtk3: Fix icons not loading properly on Gtk 3.16 and older.
  * Gtk3: Fix high CPU load.
* Thu Mar 24 2016 sor.alexei@meowr.ru
- Update to version 0.8.12.2:
  * Use /usr/local/ as a default prefix (alterable with the
  - -prefix= setup.py option).
  * Fix --with-gtk= option not working sometimes.
  * Fix highlight of "Ctrl" visual in hotkey selection dialog.
  * Gtk3: Don't show category titles in several lines.
  * Gtk3: Fix CCSM not shrinking back after upsizing to a certain
    point.
  * Gtk2: Fix a segfault on rare installations when clicking on
    list items.
- Add a missing python-gobject-cairo dependency.
* Wed Feb 17 2016 sor.alexei@meowr.ru
- Update to 0.8.12.1:
  * Fix bad behaviour in handling Ctrl key.
  * Custom hotkey selection now works properly.
* Sat Feb 13 2016 sor.alexei@meowr.ru
- Update to 0.8.12:
  * Replace PyGObject2, PyGtk2 dependency with PyGObject3.
  * New minimal Gtk requirements are: either Gtk 2.24.10+ or
    Gtk 3.2+.
  * Add support for specialised font family widget.
  * Fix window grabbing by title or ID.
  * Do not allow mods+Escape to be bound.
  * Add more plugin icons from compiz-plugins-experimental, and add
    plugin-matecompat.
  * Drop libsexy optional dependency.
  * Fix vertical alignment of the text on the stylized keys
    (Shift, Super, Ctrl, Alt).
  * Add additional Compiz 0.9.x support, no action is required for
    either Compiz.
- Remove unsexy.patch: unsexied upstream.
* Sat Dec 19 2015 sor.alexei@meowr.ru
- Use a better upstream tarball.
* Mon Nov  9 2015 sor.alexei@meowr.ru
- Update to 0.8.9.
- Update dependencies.
- Remove compizconfig-settings-manager-profile-extensions.patch:
  fixed upstream.
- Add compizconfig-settings-manager-lang package.
- Provide ccsm.
- Do not make a bindir symlink.
- Generate icon cache.
* Mon May 12 2014 ku.b@gmx.de
- unlink from Factory
* Mon May 12 2014 ku.b@gmx.de
- repair package due to broken link in Factory
- remove Obsoletes ccs-settings
- repair License
- remove outdated 1110 version section
* Thu Nov 11 2010 ku.b@gmx.de
- add the requirement for a compiz version less than 0.9
- require a version less than 0.9 of python-ccm
* Thu May 27 2010 dimstar@opensuse.org
- Split the python backend out in it's own package and have ccsm
  frontend require it.
* Fri Nov 13 2009 dimstar@opensuse.org
- Update to version 0.8.4:
  + Remove obsolete icons
  + Speed up startup by loading icons in the background
* Sat Oct  3 2009 aj@suse.de
- Don't warn about missing sexy-python, it's not available at all
  in openSUSE (unsexy.patch)
- Package is noarch for openSUSE 11.2.
* Fri Aug 21 2009 dimstar@opensuse.org
- Add new python macros for openSUSE <= 11.1
* Sun Aug  9 2009 coolo@novell.com
- use new python macros
* Thu Jan 29 2009 rodrigo@novell.com
- Add compizconfig-settings-manager-profile-extensions.patch (bgo#458343)
* Mon Sep 29 2008 rodrigo@novell.com
- Review and merge changes from X11:Compiz
* Wed Sep 17 2008 cyberorg@opensuse.org
- Release 0.7.8
- l10n updates
- Add startup notification and optional dbus single-instance support
- Make use of the new tooltip system introduced in GTK 2.12
* Tue Jul  1 2008 mhopf@suse.de
- Update from buildservice.
* Sat May 31 2008 cyberorg@opensuse.org
- update to 0.7.6
  - Check if an action conflicts with another plugin when enabling
    a plugin
  - Internal action bindings will now only conflict with global
    bindings; internal actions in different plugins can have the
    same bindings.
  - Rewrote plugin overview page
  - Changed native size of category icons to 32x32
  - Internal code refactoring and bug fixes
* Mon Apr 14 2008 mhopf@suse.de
- Update from buildservice.
* Thu Apr  3 2008 cyberorg@cyberorg.info
- 0.7.4 release
- Advance search rewrite
- Add --version/-v command line switch
- Many GUI improvements
* Fri Mar  7 2008 cyberorg@opensuse.org
- 0.7.2 development release
- Action settings were split into button, key, and edge settings, each using
  its own widget.
- Match settings can be edited with a simple editor that supports easy
  grabbing of window properties
- Advanced Search page was improved
- New icons for some plugins
- Minor adaptations and fixes
* Sat Feb  9 2008 cyberorg@cyberorg.info
- sync to latest git
* Tue Dec  4 2007 cyberorg@cyberorg.info
- sync to latest git
- many GUI improvements
- key binding improvements
- file selection improvements
* Tue Oct 16 2007 cyberorg@cyberorg.info
- Update to release 0.6.0
- Translation updates
- Key binding fixes and GUI improvements
* Sat Aug 25 2007 cyberorg@cyberorg.info
- EdgeSelector improvements
- Key grabber fixes
- Rework key actions handling
- Made plugin tabs scrollable
* Fri Aug 24 2007 cyberorg@cyberorg.info
- Sync to the latest git.
- new action settings rework
- New GUI improvements
* Fri Aug 17 2007 cyberorg@cyberorg.info
- Symlink ccsm to compiz-config-settings-manager.
* Mon Aug 13 2007 cyberorg@cyberorg.info
- Update to 0.5.2 release.
- Added missing icons
- Profile page fixes
- Options rearrangement - general option first
- Fixed bug with files without type extension
* Wed Aug  8 2007 schwab@suse.de
- Fix specfile.
* Tue Aug  7 2007 aj@suse.de
- Fix packaging problems.
* Mon Aug  6 2007 dreveman@suse.de
- Install with correct prefix
- Do not require libcompizconfig-backend
- Use %%suse_update_desktop_file macro
* Mon Aug  6 2007 dreveman@suse.de
- Initial version of package
